|
Boost-Commit : |
From: daniel_james_at_[hidden]
Date: 2008-07-06 08:41:09
Author: danieljames
Date: 2008-07-06 08:41:09 EDT (Sun, 06 Jul 2008)
New Revision: 47132
URL: http://svn.boost.org/trac/boost/changeset/47132
Log:
'Bias' should be 'basis'.
Text files modified:
trunk/libs/unordered/examples/hash_functions/fnv-1.hpp | 16 ++++++++--------
1 files changed, 8 insertions(+), 8 deletions(-)
Modified: trunk/libs/unordered/examples/hash_functions/fnv-1.hpp
==============================================================================
--- trunk/libs/unordered/examples/hash_functions/fnv-1.hpp (original)
+++ trunk/libs/unordered/examples/hash_functions/fnv-1.hpp 2008-07-06 08:41:09 EDT (Sun, 06 Jul 2008)
@@ -9,12 +9,12 @@
namespace hash
{
- template <std::size_t FnvPrime, std::size_t OffsetBias>
+ template <std::size_t FnvPrime, std::size_t OffsetBasis>
struct basic_fnv_1
{
std::size_t operator()(std::string const& text) const
{
- std::size_t hash = OffsetBias;
+ std::size_t hash = OffsetBasis;
for(std::string::const_iterator it = text.begin(), end = text.end();
it != end; ++it)
{
@@ -26,12 +26,12 @@
}
};
- template <std::size_t FnvPrime, std::size_t OffsetBias>
+ template <std::size_t FnvPrime, std::size_t OffsetBasis>
struct basic_fnv_1a
{
std::size_t operator()(std::string const& text) const
{
- std::size_t hash = OffsetBias;
+ std::size_t hash = OffsetBasis;
for(std::string::const_iterator it = text.begin(), end = text.end();
it != end; ++it)
{
@@ -43,7 +43,7 @@
}
};
// TODO: Select Bias & Prime base on the size of std::size_t.
//
// 32 bit FNV_prime = 16777619
// 64 bit FNV_prime = 1099511628211
@@ -60,12 +60,12 @@
// 128 bit FNV_prime = 309485009821345068724781401
// 256 bit FNV_prime = 374144419156711147060143317175368453031918731002211
- const std::size_t fnv_offset_bias = 2166136261u;
+ const std::size_t fnv_offset_basis = 2166136261u;
// 64 bit offset_basis = 14695981039346656037
// 128 bit offset_basis = 275519064689413815358837431229664493455
// 256 bit offset_basis = 100029257958052580907070968620625704837092796014241193945225284501741471925557
- typedef basic_fnv_1<fnv_prime, fnv_offset_bias> fnv_1;
- typedef basic_fnv_1a<fnv_prime, fnv_offset_bias> fnv_1a;
+ typedef basic_fnv_1<fnv_prime, fnv_offset_basis> fnv_1;
+ typedef basic_fnv_1a<fnv_prime, fnv_offset_basis> fnv_1a;
}
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
@@ -43,7 +43,7 @@
}
};
- // TODO: Select Bias & Prime base on the size of std::size_t.
+ // TODO: Select Basis & Prime base on the size of std::size_t.
//
// 32 bit FNV_prime = 16777619